@@ -4,24 +4,33 @@ from tabulate import tabulate
 from enum import Enum
 import json
 
-Textract_Pretty_Print = Enum('Textract_Pretty_Print', ["WORDS", "LINES", "FORMS", "TABLES"], start=0)
+Textract_Pretty_Print = Enum('Textract_Pretty_Print',
+                             ["WORDS", "LINES", "FORMS", "TABLES"],
+                             start=0)
 
 
-def get_string(textract_json_string: str, output_type: Optional[List[Textract_Pretty_Print]] = None):
+def get_string(textract_json_string: str,
+               output_type: Optional[List[Textract_Pretty_Print]] = None):
     result_value = ""
     for t in output_type:
         if t == Textract_Pretty_Print.WORDS:
-            result_value += get_words_string(textract_json_string=textract_json_string)
+            result_value += get_words_string(
+                textract_json_string=textract_json_string)
         if t == Textract_Pretty_Print.LINES:
-            result_value += get_lines_string(textract_json_string=textract_json_string)
+            result_value += get_lines_string(
+                textract_json_string=textract_json_string)
         if t == Textract_Pretty_Print.FORMS:
-            result_value += get_forms_string(textract_json_string=textract_json_string)
+            result_value += get_forms_string(
+                textract_json_string=textract_json_string)
         if t == Textract_Pretty_Print.TABLES:
-            result_value += get_tables_string(textract_json_string=textract_json_string)
+            result_value += get_tables_string(
+                textract_json_string=textract_json_string)
     return result_value
 
 
-def convert_table_to_list(trp_table: trp.Table, with_confidence: bool = False, with_geo: bool = False) -> List:
+def convert_table_to_list(trp_table: trp.Table,
+                          with_confidence: bool = False,
+                          with_geo: bool = False) -> List:
     rows_list = list()
     for _, row in enumerate(trp_table.rows):
         one_row = list()
@@ -47,22 +56,24 @@ def get_tables_string(textract_json_string: str,
     with_confidence: output confidence scores as well
     with_geo: output geo information as well
     """
-    doc= trp.Document(json.loads(textract_json_string))
+    doc = trp.Document(json.loads(textract_json_string))
     result_value = ""
     for page in doc.pages:
         for table in page.tables:
-            result_value += result_value + tabulate(convert_table_to_list(
+            result_value += tabulate(convert_table_to_list(
                 table, with_confidence=with_confidence, with_geo=with_geo),
-                                                    tablefmt=table_format) + "\n\n"
+                                     tablefmt=table_format) + "\n\n"
 
     return result_value
 
 
-def get_forms_string(textract_json_string: str, with_confidence: bool = False, with_geo: bool = False) -> str:
+def get_forms_string(textract_json_string: str,
+                     with_confidence: bool = False,
+                     with_geo: bool = False) -> str:
     """
     returns string with key-values printed out in format: key: value
     """
-    doc= trp.Document(json.loads(textract_json_string))
+    doc = trp.Document(json.loads(textract_json_string))
     result_value = ""
     for page in doc.pages:
         for field in page.form.fields:
@@ -83,11 +94,12 @@ def get_forms_string(textract_json_string: str, with_confidence: bool = False, w
     return result_value
 
 
-def get_lines_string(textract_json_string: str, with_page_number: bool = False) -> str:
+def get_lines_string(textract_json_string: str,
+                     with_page_number: bool = False) -> str:
     """
     returns string with lines seperated by \n
     """
-    doc= trp.Document(json.loads(textract_json_string))
+    doc = trp.Document(json.loads(textract_json_string))
     i = 0
     result_value = ""
     for page in doc.pages:
@@ -99,11 +111,12 @@ def get_lines_string(textract_json_string: str, with_page_number: bool = False)
     return result_value
 
 
-def get_words_string(textract_json_string: str, with_page_number: bool = False) -> str:
+def get_words_string(textract_json_string: str,
+                     with_page_number: bool = False) -> str:
     """
     returns string with words seperated by \n
     """
-    doc= trp.Document(json.loads(textract_json_string))
+    doc = trp.Document(json.loads(textract_json_string))
     i = 0
     result_value = ""
     for page in doc.pages:
